<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#xA0;">]>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ercot="http://www.ercot.com/functions" xmlns:xs="http://www.w3.org/2001/XMLSchema">
	
	<xsl:param name="path"/>

	<xsl:output method="html" indent="yes"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
		doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" encoding="UTF-8"/>

	<!-- converts -444444.00 to ($444,444.00) OR 444444.00 to $444,444.00 -->
	<xsl:function name="ercot:number-to-dollar" as="xs:string">
		<xsl:param name="number" as="xs:string?"/>
		<xsl:variable name="digits"
			select="if ($number[contains(.,'-')]) then number(substring-after($number,'-')) else number($number)"/>
		<xsl:choose>
			<xsl:when test="string-length($number) = 0">
				<xsl:sequence select="xs:string(' ')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:sequence
					select="xs:string( if ($number[contains(.,'-')]) 
					then concat('($' , format-number($digits, '#,##0.00') , ')') 
					else concat('$', format-number($digits, '#,##0.00') ) )"
				/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>

	<xsl:template match="/DEF_Invoice">
		<xsl:variable name="time" select="xs:time(concat(SummarySection/InvoiceDueTime, ':00'))"
			as="xs:time"/>

		<html>
			<head>
				<title>Default Uplift Invoice</title>
				<style type="text/css">
					body,td,th {
					    font-family: Calibri, sans-serif;
					    font-size: 9pt !important;
					}
					.subtotal td {
					    border-color: black;
					    border-top-style: solid;
					    border-top-width: 1px;
					}
					.total td {
					    border-color: black;
					    border-top-style: solid;
					    border-top-width: thin;
					}
					.net td {
					    border-color: black;
					    border-top-style: solid;
					    border-top-width: thin;
					    border-bottom-style: solid;
					    border-bottom-width: thin;
					    font-weight: bold;
					    text-align: right;
					}
					.remittance tr td {
					    border-color: black;
					    border-bottom-style: solid;
					    border-bottom-width: 1px;
					}
					.bold {
					    font-weight: bold;
					}
					.padding-normal {
					    padding: 1px 3px 1px 3px;
					}
					.padding-remittance {
					    padding: 5px 3px 4px 3px;
					}
					.highlight {
					    background-color: #C5D9F1;
					}
					.paragraph {
					    line-height: 125%;
					}
					.uplift-invoice-data-header {
					    padding: 10px 3px 10px 3px;
					}
					.uplift-invoice-data-header th {
					    font-weight: normal;
					}
					.detail-start {
					    border-color: black;
					    border-bottom-style: solid;
					    border-bottom-width: thin;
					}
					.invoice-type {
					    text-transform: uppercase;
					    font-weight: bold;
					    text-align: right;
					    padding-right: 3px;
					    vertical-align: bottom;
					}</style>
			</head>
			<body>
				<table width="700" border="0" cellspacing="0" cellpadding="0">
					<tr>
						<td>
							<img src="{$path}images/logo_trans.gif" width="126" height="51"
								alt="ERCOT Logo"/>
						</td>
						<td class="invoice-type">Default Uplift Invoice</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="700" border="0" cellspacing="0" cellpadding="0">
								<colgroup align="right" class="padding-normal"/>
								<colgroup align="right" class="bold padding-normal"/>
								<tr>
									<td colspan="2">
										<xsl:text>&nbsp;</xsl:text>
									</td>
								</tr>
								<tr>
									<td>Invoice No:</td>
									<td>
										<xsl:value-of select="SummarySection/InvoiceID"/>
									</td>
								</tr>
								<tr>
									<td>Invoice Date:</td>
									<td>
										<xsl:value-of select="SummarySection/InvoiceDate"/>
									</td>
								</tr>
								<tr>
									<td colspan="2">
										<xsl:text>&nbsp;</xsl:text>
									</td>
								</tr>
								<tr>
									<td> Payments are due to ERCOT by <xsl:value-of
											select="format-time($time, 
											'[h]:[m01] [PN]')"
										/> (CPT) on: </td>
									<td>
										<xsl:value-of select="SummarySection/InvoiceDueDate"/>
									</td>
								</tr>
								<tr>
									<td> Payments will be made to Invoice Recipients by
											<xsl:value-of
											select="format-time($time, 
											'[h]:[m01] [PN]')"
										/> (CPT) on: </td>
									<td>
										<xsl:value-of select="SummarySection/InvoicePayoutDate"/>
									</td>
								</tr>
								<tr>
									<td colspan="2">
										<xsl:text>&nbsp;</xsl:text>
									</td>
								</tr>
								<tr>
									<td class="bold">AMOUNT OWED (DUE):</td>
									<td class="highlight">
										<xsl:value-of
											select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
										/>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight">
						<td colspan="2" class="padding-normal">INVOICE RECIPIENT</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="700" border="0" cellpadding="0" cellspacing="0">
								<colgroup width="100" class="padding-normal"/>
								<colgroup class="bold"/>
								<tr>
									<td>Name:</td>
									<td>
										<xsl:value-of
											select="AccountSection/RecipientSection/RecipientAccountName"
										/>
									</td>
								</tr>
								<tr>
									<td>ID:</td>
									<td>
										<xsl:value-of
											select="AccountSection/RecipientSection/RecipientAccountID"
										/>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="700" border="0" cellspacing="0" cellpadding="0">
								<colgroup align="left" width="30%"/>
								<colgroup align="center" width="15"/>
								<colgroup align="left" width="15%"/>
								<colgroup align="right" width="20%"/>
								<colgroup align="right" width="20%"/>
								<thead class="uplift-invoice-data-header highlight">
									<tr>
										<th>DESCRIPTION</th>
										<th>INVOICE DUE</th>
										<th>REFERENCE</th>
										<th>UPLIFTED AMOUNT</th>
										<th>BILLABLE AMOUNT</th>
									</tr>
								</thead>
								<tbody class="padding-normal">
									<xsl:for-each select="UpliftInvoiceData/UpliftGroup">
										<xsl:variable name="name" select="@name" as="xs:string"/>
										<tr>
											<td colspan="5" class="detail-start">
												<xsl:text>&nbsp;</xsl:text>
											</td>
										</tr>
										<xsl:for-each select="UpliftDetail">
											<tr>
												<td>
												<xsl:value-of select="$name"/>
												</td>
												<td>
												<xsl:choose>
												<xsl:when test="Reference != ''">
												<xsl:value-of select="InvoiceDue"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text>&nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td>
												<xsl:choose>
												<xsl:when test="Reference != ''">
												<xsl:value-of select="Reference"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:choose>
												<xsl:when test="contains(UpliftedAmount,'-')"
												>CREDIT</xsl:when>
												<xsl:otherwise>ADJUSTMENT</xsl:otherwise>
												</xsl:choose>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td>
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftedAmount)"/>
												</td>
												<td>
												<xsl:value-of
												select="ercot:number-to-dollar(BillableAmount)"/>
												</td>
											</tr>
										</xsl:for-each>
										<tr class="subtotal">
											<td colspan="3"> Subtotal - <xsl:value-of select="$name"
												/>
											</td>
											<td>
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftHeader/Subtotal)"
												/>
											</td>
											<td>
												<xsl:text>&nbsp;</xsl:text>
											</td>
										</tr>
										<tr>
											<td colspan="3"> Previous Uplift for <xsl:value-of
												select="$name"/>
											</td>
											<td>
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftHeader/PreviousUplifts)"
												/>
											</td>
											<td>
												<xsl:text>&nbsp;</xsl:text>
											</td>
										</tr>
										<tr>
											<td colspan="3">Reduction due to $2.5M cap</td>
											<td>
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftHeader/Reduction)"
												/>
											</td>
											<td> </td>
										</tr>
										<tr class="total">
											<td colspan="3"> TOTAL - <xsl:value-of select="$name"/>
											</td>
											<td>
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftHeader/Total)"
												/>
											</td>
											<td>
												<xsl:value-of
												select="ercot:number-to-dollar(BillableAmount)"/>
											</td>
										</tr>
										<tr>
											<td colspan="5"> </td>
										</tr>
									</xsl:for-each>
									<tr class="net">
										<td colspan="4">NET AMOUNT DUE</td>
										<td class="highlight">
											<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight">
						<td colspan="2" class="padding-normal">REMITTANCE INFORMATION</td>
					</tr>
					<tr>
						<td colspan="2" class="remittance">
							<table width="700" border="0" cellspacing="0" cellpadding="0">
								<colgroup align="left" width="25%" class="bold"/>
								<colgroup span="2" align="left"/>
								<thead class="padding-remittance">
									<tr>
										<th> </th>
										<th>ERCOT Account</th>
										<th>Recipient Account</th>
									</tr>
								</thead>
								<tbody class="padding-normal">
									<tr>
										<td>Account Name</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTBankName"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientBankName"
											/>
										</td>
									</tr>
									<tr>
										<td>Bank Name</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTFinancialInst"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientFinancialInst"
											/>
										</td>
									</tr>
									<tr>
										<td>ABA Routing Number</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTRoutingNum"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientRoutingNum"
											/>
										</td>
									</tr>
									<tr>
										<td>Account Number</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTBankAcctNum"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientBankAcctNum"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr>
						<td colspan="2" class="bold padding-normal">Overdue Terms</td>
					</tr>
					<tr>
						<td colspan="2" class="paragraph padding-normal">
							<xsl:value-of select="SummarySection/InvoiceTerms"/>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
