<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ercot="http://www.ercot.com/functions" xmlns:xs="http://www.w3.org/2001/XMLSchema">

	<xsl:output method="xml" indent="yes"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
		doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<xsl:param name="path"/>
	
	<xsl:template match="/">
		<xsl:apply-templates
			select="RTM_Invoice | CRRAuctionInvoice | CARD_Invoice | BalAcct_Invoice | DAM_Invoice | LateFee_Invoice | RTU_Invoice | Misc_Invoice"/>
	</xsl:template>

	<xsl:template
		match="RTM_Invoice | CRRAuctionInvoice | CARD_Invoice | BalAcct_Invoice | DAM_Invoice | LateFee_Invoice | RTU_Invoice | Misc_Invoice">

		<xsl:variable name="t" select="xs:time(concat(SummarySection/InvoiceDueTime, ':00'))"
			as="xs:time"/>

		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
				<title>Invoice</title>
				<link href="{$path}css/sett.css" rel="stylesheet" type="text/css"/>
				<script language="javascript" type="text/javascript" src="{$path}scripts/twistie.js">
					<xsl:comment>using this comment to force saxon to not reformat as script/ b/c IE doesn's support it</xsl:comment>
				</script>
				<style type="text/css">
					<xsl:comment> 
						body {background-color: #FCFBF5;} 
						.no_underline {text-decoration:none}
						.highlight{background-color: #FFE89F;}
					</xsl:comment>
					.topline td, .topline tr{border-color:#330000; border-top: 1px solid black;}
				</style>
				<script language="javascript" type="text/javascript">
					<![CDATA[
					
					function goToDetail(id) {
					
					document.getElementById('summary').style.display = 'none';
					document.getElementById('detail').style.display = 'block';
					//document.getElementById('d' + id).class.value = 'highlight';
					
					var trElem = document.getElementById('d' +id); 

					trElem.setAttribute("class", "highlight"); 
					trElem.setAttribute("classname", "highlight"); 
					
					}
					
					function goToSummary(id) {
					
					document.getElementById('summary').style.display = 'block';
					document.getElementById('detail').style.display = 'none';
					
					var trElem = document.getElementById('d' + id); 
					trElem.setAttribute("class", "normal"); 
					trElem.setAttribute("classname", "normal"); 
					
					}
					]]>
				</script>
			</head>

			<body>
				<table width="700" border="0" cellpadding="0" cellspacing="0">
					<tr>
						<td>
							<table width="700" border="0" cellspacing="0" cellpadding="0">
								<tr>
									<td width="126">
										<img src="{$path}images/logo_trans.gif" width="126" height="51"
											alt="ERCOT logo"/>
									</td>
									<td class="head1">
										<xsl:choose>
											<xsl:when test="name(.) eq 'CRRAuctionInvoice'">CRR
												AUCTION INVOICE</xsl:when>
											<xsl:when test="name(.) eq 'BalAcct_Invoice'">CRR
												BALANCING ACCOUNT INVOICE</xsl:when>
											<xsl:when test="name(.) eq 'RTM_Invoice'">REAL-TIME
												MARKET INVOICE</xsl:when>
											<xsl:when test="name(.) eq 'DAM_Invoice'">DAY-AHEAD
												MARKET INVOICE</xsl:when>
											<xsl:when
												test="name(.) eq 'LateFee_Invoice' and starts-with(SummarySection/InvoiceID, 'D')"
												>DAY-AHEAD MARKET LATE FEE INVOICE</xsl:when>
											<xsl:when
												test="name(.) eq 'LateFee_Invoice' and starts-with(SummarySection/InvoiceID, 'R')"
												>REAL-TIME MARKET LATE FEE INVOICE</xsl:when>
											<xsl:when test="name(.) eq 'CARD_Invoice'">CRR AUCTION
												REVENUE DISTRIBUTION (CARD INVOICE)</xsl:when>
											<xsl:when test="name(.) eq 'RTU_Invoice'">REAL-TIME
												UPLIFT INVOICE</xsl:when>
											<xsl:when test="name(.) eq 'Misc_Invoice'">MISCELLANEOUS
												INVOICE</xsl:when>
										</xsl:choose>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td>
							<table width="700" border="0" cellspacing="0" cellpadding="0">
								<tr>
									<td width="40">
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td>
										<table width="620" border="0" cellspacing="0"
											cellpadding="0">
											<tr>
												<td colspan="2" valign="top">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="10">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="125">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
											</tr>
											<tr>
												<td colspan="3">
												<xsl:choose>
												<xsl:when test="name(.) eq 'CRRAuctionInvoice'">
												<p class="arial_70_right">Auction:</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</xsl:when>
												<xsl:when
												test="name(.) eq 'CARD_Invoice' or name(.) eq 'BalAcct_Invoice' or name(.) eq 'LateFee_Invoice' or name(.) eq 'RTU_Invoice'">
												<p class="arial_70_right">Time Period:</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</xsl:when>
												<xsl:when test="name(.) eq 'RTM_Invoice'"/>
												<xsl:when test="name(.) eq 'Misc_Invoice'">
												<p class="arial_70_right">Category:</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</xsl:when>
												</xsl:choose>
												<p class="arial_70_right">Invoice No:</p>
												<p class="arial_70_right">Invoice Date:</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												<!--<xsl:if test="name(.) != 'BalAcct_Invoice'">-->
												<p class="arial_70_right">Payments are due to
												ERCOT by <xsl:value-of
												select="format-time($t, '[h]:[m01] [PN]', 'en', (), ())"
												/> (CPT) on:</p>
												<!--</xsl:if>-->
												<p class="arial_70_right">Payments will be made to
												Invoice Recipients by <xsl:value-of
												select="format-time($t, '[h]:[m01] [PN]', 'en', (), ())"
												/> (CPT) on:</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												<p class="arial_70_right">
												<strong>AMOUNT OWED (DUE):</strong>
												</p>
												</td>
												<td width="10">
												<p class="arial_70_rightbold">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</td>
												<td width="150">
												<xsl:choose>
												<xsl:when test="name(.) eq 'CRRAuctionInvoice'">
												<p class="arial_70_right">
												<xsl:value-of
												select="concat(SummarySection/AuctionType, '-', SummarySection/TimePeriod)"
												/>
												</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</xsl:when>
												<xsl:when
												test="name(.) eq 'CARD_Invoice' or name(.) eq 'BalAcct_Invoice' or name(.) eq 'LateFee_Invoice'  or name(.) eq 'RTU_Invoice'">
												<p class="arial_70_rightbold">
												<xsl:value-of select="SummarySection/TimePeriod"/>
												</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</xsl:when>
												<xsl:when test="name(.) eq 'RTM_Invoice'"/>
												<xsl:when test="name(.) eq 'Misc_Invoice'">
												<p class="arial_70_rightbold">
												<xsl:value-of select="SummarySection/Category"/>
												</p>
												<p class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												</xsl:when>
												</xsl:choose>
												<p class="arial_70_rightbold">
												<xsl:value-of select="SummarySection/InvoiceID"/>
												</p>
												<p class="arial_70_rightbold">
												<xsl:value-of select="SummarySection/InvoiceDate"
												/>
												</p>
												<p class="arial_70_rightbold">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												<!--<xsl:if test="name(.) != 'BalAcct_Invoice'">-->
												<p class="arial_70_rightbold">
												<xsl:value-of
												select="SummarySection/InvoiceDueDate"/>
												</p>
												<!--</xsl:if>-->
												<p class="arial_70_rightbold">
												<xsl:value-of
												select="SummarySection/InvoicePayoutDate"/>
												</p>
												<p class="arial_70_rightbold">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</p>
												<p class="arial_70_rightboldShaded">
												<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/(InvoiceTotalAmount | InvoiceTotal))"
												/>
												</p>
												</td>
											</tr>
											<tr>
												<td width="185">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="200">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="10">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="125">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
											</tr>
											<tr>
												<td colspan="5" class="titlebar">INVOICE
												RECIPIENT</td>
											</tr>

											<tr>
												<td colspan="5" style="padding-top:5px">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td>
												<p class="arial_70_leftInd">Name:</p>
												<p class="arial_70_leftInd">ID:</p>
												</td>
												<td width="10">
												<img src="{$path}images/dot_clear.gif" width="10"
												height="1"/>
												</td>
												<td width="100%">
												<p class="arial_70_leftbold">
												<xsl:value-of
												select="AccountSection/(CRRSection | RecipientSection | QSESection)/(CRRAccountName | RecipientAccountName | QSEAccountName | AccountName)"
												/>
												</p>
												<p class="arial_70_leftbold">
												<xsl:value-of
												select="AccountSection/(CRRSection | RecipientSection | QSESection)/(CRRAccountID | RecipientAccountID | QSEAccountID | AccountID)"
												/>
												</p>
												</td>
												</tr>
												</table>
												</td>
											</tr>
											<tr>
												<td height="8" colspan="5">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
											</tr>

										</table>
										<xsl:choose>
											<xsl:when test="name(.) eq 'CRRAuctionInvoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr style="padding-bottom:5px">
												<td width="100" class="titlebar">CRR 
												ID</td>
												<td width="100" class="titlebar">HEDGE TYPE</td>
												<td width="100" class="titlebar">PCRR TYPE</td>
												<td width="60" class="titlebarRight">BUY/SELL</td>
												<td width="100" class="titlebar">AMOUNT</td>
												<td width="80" class="titlebarRight">CLEARING PRICE</td>
												<td width="80" class="titlebarRight">AWARD FEE</td>
												</tr>
												<xsl:for-each select="InvoiceData/InvoiceDetail">
												<tr>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="ProductID"/>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="HedgeType"/>
												</td>
												<td class="arial_70_leftInd_bdr">
												<xsl:choose>
												<xsl:when test="PCRRType != ''">
												<xsl:value-of select="PCRRType"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td class="arial_70_leftInd_bdr">
												<xsl:value-of select="BuyerSeller"/>
												</td>
												<td width="100" class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(Amount)"/>
												</td>
													<td class="arial_70_right_bdr">
													<xsl:choose>
														<xsl:when test="HedgeType = 'OPTPAMT' and BuyerSeller = 'B' and ClearingPrice != ''">
															<xsl:value-of select="ercot:number-to-dollar(ClearingPrice)"/>
														</xsl:when>
														<xsl:otherwise>
															<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
														</xsl:otherwise>
													</xsl:choose>
												</td>
													<td class="arial_70_right_bdr"><xsl:choose>
														<xsl:when test="HedgeType = 'OPTPAMT' and BuyerSeller = 'B' and ClearingPrice != ''">
															<xsl:choose>
																<xsl:when test="AwardFee != ''">
																	<xsl:value-of select="ercot:number-to-dollar(AwardFee)"/>
																</xsl:when>
																<xsl:otherwise><xsl:value-of select="ercot:number-to-dollar('0')"/></xsl:otherwise>
															</xsl:choose>
														</xsl:when>
														<xsl:otherwise>
															<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
														</xsl:otherwise>
													</xsl:choose>
													</td>
												</tr>
												</xsl:for-each>
												<tr>
													<td class="arial_70_left_bdr" style="border-top:black solid 2px;border-bottom-width:0px">TOTAL</td>
													<td class="arial_70_left_bdr" style="border-top:black solid 2px;border-bottom-width:0px"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
													<td class="arial_70_left_bdr" style="border-top:black solid 2px;border-bottom-width:0px"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
													<td class="arial_70_left_bdr" style="border-top:black solid 2px;border-bottom-width:0px"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
													<td class="arial_70_right_bdr" style="border-top:black solid 2px;border-bottom-width:0px">
														<xsl:choose>
															<xsl:when test="SummarySection/InvoiceSubtotalAmount != ''">
																<xsl:value-of select="ercot:number-to-dollar(SummarySection/InvoiceSubtotalAmount)"/>
															</xsl:when>
															<xsl:otherwise>
																<!-- make it backwards compatible -->
																<xsl:value-of select="ercot:number-to-dollar(SummarySection/InvoiceTotalAmount)"/>
															</xsl:otherwise>
														</xsl:choose>
													</td>
													<td class="arial_70_left_bdr" style="border-top:black solid 2px;border-bottom-width:0px"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
													<td class="arial_70_right_bdr" style="border-top:black solid 2px;border-bottom-width:0px">
														<xsl:choose>
															<xsl:when test="SummarySection/InvoiceSubtotalAwardFees != ''">
																<xsl:value-of select="ercot:number-to-dollar(SummarySection/InvoiceSubtotalAwardFees)"/>
															</xsl:when>
															<!-- make it backwards compatible -->
															<xsl:when test="SummarySection/InvoiceSubtotalAmount != ''">
																<xsl:value-of select="ercot:number-to-dollar('0')"/>
															</xsl:when>
															<xsl:otherwise>
																<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
															</xsl:otherwise>
														</xsl:choose>
													</td>
												</tr>
												</table>
											</xsl:when>
											<!-- Comment this out -->
											<!--<xsl:when test="name(.) eq 'BalAcct_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td class="titlebar">DESCRIPTION</td>
												<td width="130" class="titlebarRight">AMOUNT</td>
												</tr>
												<xsl:for-each select="InvoiceData/InvoiceDetail">
												<tr>
												<td class="arial_70_leftInd_bdr">
												<b>
												<xsl:value-of select="ChargeType"/>
												</b> - <xsl:value-of select="Description"/>
												</td>
												<td class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(Amount)"/>
												</td>
												</tr>
												</xsl:for-each>
												<tr>
												<td class="arial_70_rightIndBold_bdr"
												style="padding-right:10px">AMOUNT OWED (DUE):</td>
												<td
												style="background-color: #d7e2f2; border-bottom-width: 2px;border-bottom-style: solid;border-bottom-color: #999999;"
												class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
												/>
												</td>
												</tr>
												</table>
											</xsl:when>-->
											<xsl:when test="name(.) eq 'DAM_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td width="185" class="titlebar">category</td>
												<td width="200" class="titlebar">statement id </td>
												<td width="100" class="titlebar">operating day </td>
												<td width="10" class="titlebarRight">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="125" class="titlebarRight">statement
												amount </td>

												</tr>
												<xsl:for-each select="InvoiceData/InvoiceDetail">
												<tr>
												<td width="185" class="arial_70_leftIndBold_bdr">
												<xsl:value-of select="StatementType"/>
												</td>
												<td width="200" class="arial_70_leftInd_bdr">
												<xsl:value-of select="StatementID"/>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="OperatingDate"/>
												</td>
												<td width="10" class="arial_70_right_red_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="125" class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(StatementAmount)"/>
												</td>

												</tr>
												</xsl:for-each>
												</table>
											</xsl:when>
											<xsl:when test="name(.) eq 'LateFee_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td class="titlebar">LATE FEE CALCULATION
												DATE</td>
												<td class="titlebarRight">
												<xsl:choose>
												<xsl:when
												test="starts-with(SummarySection/InvoiceID, 'R')"
												>RTM LATE FEE CHARGES</xsl:when>
												<xsl:otherwise>DAM LATE FEE
												CHARGES</xsl:otherwise>
												</xsl:choose>
												</td>
												<td class="titlebarRight">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="130" class="titlebarRight">
												<xsl:choose>
												<xsl:when
												test="starts-with(SummarySection/InvoiceID, 'R')"
												>RTM Late Fee Credits</xsl:when>
												<xsl:otherwise> DAM Late Fee
												Credits</xsl:otherwise>
												</xsl:choose>
												</td>
												</tr>
												<xsl:for-each select="InvoiceData/InvoiceDetail">
												<tr>
												<td class="arial_70_leftInd_bdr">
												<xsl:value-of select="CalcDate"/>
												</td>
												<td class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar-not-rounded(CH_Amount)"
												/>
												</td>
												<td class="arial_70_rightInd_bdr_lite">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td class="arial_70_rightInd_bdr_lite">
												<xsl:value-of
												select="ercot:number-to-dollar-not-rounded(CR_Amount)"
												/>
												</td>
												</tr>
												</xsl:for-each>
												<tr>
												<td class="arial_70_leftIndBold">Subtotals</td>
												<td class="arial_70_rightbold">
												<xsl:value-of
												select="ercot:number-to-dollar(InvoiceData/CHInvoiceSubTotal)"
												/>
												</td>
												<td class="arial_70_rightbold">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td class="arial_70_rightbold">
												<xsl:value-of
												select="ercot:number-to-dollar(InvoiceData/CRInvoiceSubTotal)"
												/>
												</td>
												</tr>
												<tr>
												<td class="arial_70_leftIndBold">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td class="arial_70_rightbold">TOTAL <xsl:choose>
												<xsl:when
												test="starts-with(SummarySection/InvoiceID, 'R')"
												>RTM</xsl:when>
												<xsl:otherwise>DAM</xsl:otherwise>
												</xsl:choose> LATE FEES </td>

												<td class="arial_70_rightbold">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td class="arial_70_rightboldShaded">
												<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
												/>
												</td>
												</tr>
												</table>
											</xsl:when>
											<xsl:when test="name(.) eq 'CARD_Invoice' or name(.) eq 'BalAcct_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td class="titlebar">DESCRIPTION</td>
												<td width="120" class="titlebar">CATEGORY</td>
												<td width="100" class="titlebarRight">MONTHLY
												TOTALS</td>
												<td width="100" class="titlebarRight">BILLABLE
												AMOUNT</td>
												</tr>
												<xsl:for-each-group
												select="InvoiceData/descendant::VersionDetail"
												group-by="BillDetermCode">
												<xsl:for-each select="current-group()">
												<tr>
												<td
												class="arial_70_leftInd{if (position() > 1 and .[last()]) then '_bdr' else ''}">
												<xsl:choose>
												<xsl:when test="position() = 1"><b>
												<xsl:value-of select="BillDetermCode"/>
												</b> - <xsl:value-of select="Description"
												/></xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
													<td class="arial_70_leftInd{if (position() > 1 and .[last()]) then '_bdr' else ''}">
														<xsl:value-of select="../InvoiceVersion"/>
														<xsl:choose>
															<xsl:when test="name(.) eq 'CARD_Invoice'">Distribution</xsl:when>
															<xsl:when test="name(.) eq 'BalAcct_Invoice'">&amp;nbsp;</xsl:when>
														</xsl:choose>
												</td>		
												<td
												class="arial_70_right{if (position() > 1 and .[last()]) then '_bdr' else ''}">
												<xsl:value-of
												select="ercot:number-to-dollar(Amount)"/>
												</td>
												<td width="125"
												class="arial_70_right{if (position() > 1 and .[last()]) then '_bdr' else ''}">
												<xsl:value-of
												select="ercot:number-to-dollar(BillAmount)"/>
												</td>
												</tr>
												</xsl:for-each>
												</xsl:for-each-group>
												<xsl:choose>
													<xsl:when test="name(.) eq 'BalAcct_Invoice'"> 
														<tr class="topline">
															<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
															<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
															<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
															<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
														</tr>
													</xsl:when>
												</xsl:choose>		
												<xsl:for-each select="InvoiceData/InvoiceDetail">
												<tr>
												<td class="arial_70_leftInd">
												<xsl:choose>
												<xsl:when test="position() = 1">
												<b>TOTALS</b>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td class="arial_70_leftInd"><xsl:value-of select="InvoiceVersion"/>
												<xsl:choose>
													<xsl:when test="name(.) eq 'BalAcct_Invoice'"> 
														&amp;nbsp;
													</xsl:when>
													<xsl:otherwise>
														Distribution
													</xsl:otherwise>
												</xsl:choose>
												</td>											
												<td class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="125" class="arial_70_right">
												<xsl:value-of
												select="if (SubTotal eq 'No Activity') then 'No Activity' else ercot:number-to-dollar(SubTotal)"/>
												</td>
												</tr>
												</xsl:for-each>
												</table>
											</xsl:when>
											<xsl:when test="name(.) eq 'RTM_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td width="120" class="titlebar">category</td>
												<td width="200" class="titlebar">statement id </td>
												<td width="100" class="titlebar">operating day </td>
												<td width="100" class="titlebarRight">statement
												amount </td>
												<td width="10" class="titlebar">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100" class="titlebar">subtotal</td>
												</tr>
												<tr>
												<td height="3" colspan="6">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												</tr>
												<xsl:for-each-group
												select="InvoiceData/InvoiceDetail"
												group-by="StatementType">

												<xsl:sort
												select="current-grouping-key() eq 'RTM_RESETTLEMENT'"/>
												<xsl:sort
												select="current-grouping-key() eq 'RTM_TRUEUP'"/>
												<xsl:sort
												select="current-grouping-key() eq 'RTM_FINAL'"/>
												<xsl:sort
												select="current-grouping-key() eq 'RTM_INITIAL'"/>





												<xsl:for-each
												select="current-group()/.[StatementType eq 'RTM_INITIAL']">
												<tr>
												<td width="120" class="arial_70_leftIndBold_bdr">
												<xsl:choose>
												<xsl:when test="position() = 1">Initial
												Statements</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="200" class="arial_70_leftInd_bdr">
												<xsl:value-of select="StatementID"/>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="OperatingDate"/>
												</td>
												<td width="100" class="arial_70_right_bdr">
												<xsl:value-of
												select="if (StatementAmount != '') then ercot:number-to-dollar(StatementAmount) else ''"
												/>
												</td>
												<td class="arial_70_leftInd_bdr" width="10">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												</tr>
												</xsl:for-each>



												<xsl:for-each
												select="current-group()/.[StatementType eq 'RTM_FINAL']">
												<tr>
												<td width="120" class="arial_70_leftIndBold_bdr">
												<xsl:choose>
												<xsl:when test="position() = 1">Final Statements </xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="200" class="arial_70_leftInd_bdr">
												<xsl:value-of select="StatementID"/>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="OperatingDate"/>
												</td>
												<td width="100" class="arial_70_right_bdr">
												<xsl:value-of
												select="if (StatementAmount != '') then ercot:number-to-dollar(StatementAmount) else ''"
												/>
												</td>
												<td class="arial_70_leftInd_bdr" width="10">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												</tr>
												</xsl:for-each>

												<xsl:for-each
												select="current-group()/.[StatementType eq 'RTM_TRUEUP']">
												<tr>
												<td width="120" class="arial_70_leftIndBold_bdr">
												<xsl:choose>
												<xsl:when test="position() = 1">True-Up
												Statements</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="200" class="arial_70_leftInd_bdr">
												<xsl:value-of select="StatementID"/>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="OperatingDate"/>
												</td>
												<td width="100" class="arial_70_right_bdr">
												<xsl:value-of
												select="if (StatementAmount != '') then ercot:number-to-dollar(StatementAmount) else ''"
												/>
												</td>
												<td class="arial_70_leftInd_bdr" width="10">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												</tr>
												</xsl:for-each>

												<xsl:for-each
												select="current-group()/.[StatementType eq 'RTM_RESETTLEMENT']">
												<tr>
												<td width="120" class="arial_70_leftIndBold_bdr">
												<xsl:choose>
												<xsl:when test="position() = 1">Resettlement
												Statements</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="200" class="arial_70_leftInd_bdr">
												<xsl:value-of select="StatementID"/>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:value-of select="OperatingDate"/>
												</td>
												<td width="100" class="arial_70_right_bdr">
												<xsl:value-of
												select="if (StatementAmount != '') then ercot:number-to-dollar(StatementAmount) else ''"
												/>
												</td>
												<td class="arial_70_leftInd_bdr" width="10">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100" class="arial_70_leftInd_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												</tr>
												</xsl:for-each>

												<tr>
												<td colspan="4" class="arial_70_rightIndBold_bdr">
												<xsl:choose>
												<xsl:when test="StatementType eq 'RTM_INITIAL'"
												>Initial Statements</xsl:when>
												<xsl:when test="StatementType eq 'RTM_FINAL'"
												>Final Statements</xsl:when>
												<xsl:when test="StatementType eq 'RTM_TRUEUP'"
												>True-Up Statements</xsl:when>
												<xsl:otherwise>Resettlement
												Statements</xsl:otherwise>
												</xsl:choose> Subtotal </td>
												<td class="arial_70_rightIndBold_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100"
												class="arial_70_rightboldShaded_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(current-group()/descendant::RTMSubTotal)"
												/>
												</td>
												</tr>

												</xsl:for-each-group>
												<tr>
												<td colspan="4" class="arial_70_rightIndBold_bdr"
												>NET AMOUNT DUE </td>
												<td class="arial_70_rightIndBold_bdr">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td width="100"
												class="arial_70_rightboldShaded_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
												/>
												</td>
												</tr>
												</table>
											</xsl:when>
											<xsl:when test="name(.) eq 'RTU_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td class="titlebar">DESCRIPTION</td>
												<td width="100" class="titlebar">UPLIFTED
												INVOICE</td>
												<td width="100" class="titlebarRight">UPLIFTED
												AMOUNT</td>
												<td width="100" class="titlebarRight">BILLABLE
												AMOUNT</td>
												</tr>
												<xsl:for-each
												select="UpliftedInvoiceData/UpliftedInvoiceDetail">
												<tr>
												<td class="arial_70_leftInd_bdr"> Uplift of
												Invoice due <xsl:value-of
												select="UpliftedInvoiceDueDate"/></td>
												<td class="arial_70_leftInd_bdr">
												<xsl:value-of select="UpliftedInvoiceID"/>
												</td>
												<td class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftedInvoiceAmount)"
												/>
												</td>
												<td width="100" class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(UpliftedInvoiceBillAmount)"
												/>
												</td>
												</tr>
												</xsl:for-each>
												<tr>
												<td class="arial_70_leftInd">
												<xsl:choose>
												<xsl:when test="position() = 1">
												<b>TOTALS</b>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td class="arial_70_right">
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<!--
													<td class="arial_70_right{if (position() > 1 and .[last()]) then '_bdr' else ''}"><xsl:value-of select="format-number(sum(//TotalUpliftAmount), '$#,###.00')"/></td>
													<td width="125" class="arial_70_right"><xsl:value-of select="format-number(sum(//InvoiceTotal), '$#,###.00')"/></td>
													-->
												<td
												class="arial_70_right{if (position() > 1 and .[last()]) then '_bdr' else ''}">
												<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/TotalUpliftAmount)"
												/>
												</td>
												<td width="100" class="arial_70_right">
												<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
												/>
												</td>
												</tr>
												</table>
											</xsl:when>
											<xsl:when test="name(.) eq 'Misc_Invoice'">
												<table width="620" border="0" cellspacing="0"
												cellpadding="0">
												<tr>
												<td width="125" class="titlebar">DESCRIPTION
												1</td>
												<td width="125" class="titlebar">DESCRIPTION
												2</td>
												<td width="125" class="titlebar">DESCRIPTION
												3</td>
												<td width="125" class="titlebar">DESCRIPTION
												4</td>
												<td width="120" class="titlebarRight">AMOUNT</td>

												</tr>
												<xsl:for-each select="InvoiceData/InvoiceDetail">
												<tr>
												<td width="125" class="arial_70_leftInd_bdr">
												<xsl:choose>
												<xsl:when test="DescriptionOne != ''">
												<xsl:value-of select="DescriptionOne"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="125" class="arial_70_left_bdr">
												<xsl:choose>
												<xsl:when test="DescriptionTwo != ''">
												<xsl:value-of select="DescriptionTwo"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="125" class="arial_70_left_bdr">
												<xsl:choose>
												<xsl:when test="DescriptionThree != ''">
												<xsl:value-of select="DescriptionThree"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="125" class="arial_70_left_bdr">
												<xsl:choose>
												<xsl:when test="DescriptionFour != ''">
												<xsl:value-of select="DescriptionFour"/>
												</xsl:when>
												<xsl:otherwise>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</xsl:otherwise>
												</xsl:choose>
												</td>
												<td width="120" class="arial_70_right_bdr">
												<xsl:value-of
												select="ercot:number-to-dollar(DetailAmount)"/>
												</td>
												</tr>
												</xsl:for-each>
												</table>
											</xsl:when>
										</xsl:choose>

									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
								</tr>
								<tr>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
								</tr>
								<tr>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td class="titlebar">remittance information </td>
									<td width="40"/>
								</tr>
								<tr>
									<td/>
									<td height="8"/>
									<td/>
								</tr>
								<tr>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td>
										<table width="620" border="0" cellpadding="0"
											cellspacing="0">
											<tr>
												<td>
												<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
												</td>
												<td class="arial_70_leftbold">ERCOT Account </td>
												<td class="arial_70_leftbold">Recipient Account
												</td>
											</tr>
											<tr>
												<td class="arial_70_leftIndBold_bdr">Account Name </td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTBankName"
												/>
												</td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/(CRRSection | RecipientSection | QSESection)/(CRRBankName | RecipientBankName | QSEBankName | BankName)"
												/>
												</td>
											</tr>
											<tr>
												<td class="arial_70_leftIndBold_bdr">Bank Name </td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTFinancialInst"
												/>
												</td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/(CRRSection | RecipientSection | QSESection)/(CRRFinancialInst | RecipientFinancialInst | QSEFinancialInst | FinancialInst)"
												/>
												</td>
											</tr>
											<tr>
												<td class="arial_70_leftIndBold_bdr">ABA Routing
												Number </td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTRoutingNum"
												/>
												</td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/(CRRSection | RecipientSection | QSESection)/(CRRRoutingNum | RecipientRoutingNum | QSERoutingNum | RoutingNum)"
												/>
												</td>
											</tr>
											<tr>
												<td class="arial_70_leftIndBold_bdr">Account Number </td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTBankAcctNum"
												/>
												</td>
												<td class="arial_70_left_bdr">
												<xsl:value-of
												select="AccountSection/(CRRSection | RecipientSection | QSESection)/(CRRBankAcctNum | RecipientBankAcctNum | QSEBankAcctNum | BankAcctNum)"
												/>
												</td>
											</tr>
										</table>
									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
								</tr>

								<tr>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
								</tr>
								<!--<xsl:if test="name(.) != 'BalAcct_Invoice'">-->
								<tr>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td class="arial_70_leftbold">Overdue Terms </td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
								</tr>

								<tr>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
									<td class="arial_70_left">
										<xsl:value-of select="SummarySection/InvoiceTerms"/>
									</td>
									<td>
										<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
									</td>
								</tr>
								<!--</xsl:if>-->
								<!--
							<tr>
								<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
								<td class="arial_70_rightbold">Page 1 of 1 </td>
								<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
							</tr>
							-->

							</table>
						</td>
					</tr>
				</table>
			</body>
		</html>

	</xsl:template>

	<!-- converts -444444.00 to ($444,444.00) OR 444444.00 to $444,444.00 -->
	<xsl:function name="ercot:number-to-dollar" as="xs:string">
		<xsl:param name="number" as="xs:string"/>
		<xsl:variable name="digits"
			select="if ($number[contains(.,'-')]) then number(substring-after($number,'-')) else number($number)"/>
		<xsl:sequence
			select="xs:string( if ($number[contains(.,'-')]) 
			then concat('($' , format-number($digits, '#,##0.00') , ')') 
			else concat('$', format-number($digits, '#,##0.00') ) )"
		/>
	</xsl:function>

	<xsl:function name="ercot:number-to-dollar-not-rounded" as="xs:string">
		<xsl:param name="number" as="xs:string"/>
		<xsl:variable name="digits"
			select="if ($number[contains(.,'-')]) then number(substring-after($number,'-')) else number($number)"/>
		<xsl:sequence
			select="xs:string( if ($number[contains(.,'-')]) 
			then concat('($' , $digits , ')') 
			else concat('$', $digits ) )"
		/>
	</xsl:function>

</xsl:stylesheet>
