<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#xA0;">]>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ercot="http://www.ercot.com/functions" xmlns:xs="http://www.w3.org/2001/XMLSchema">

	<xsl:param name="path"/>

	<xsl:output method="html" indent="yes"/>
		<!--doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
		doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" encoding="UTF-8"/>-->

	<!-- converts -444444.00 to ($444,444.00) OR 444444.00 to $444,444.00 -->
	<xsl:function name="ercot:number-to-dollar" as="xs:string">
		<xsl:param name="number" as="xs:string?"/>
		<xsl:variable name="digits"
			select="if ($number[contains(.,'-')]) then number(substring-after($number,'-')) else number($number)"/>
		<xsl:choose>
			<xsl:when test="string-length($number) = 0">
				<xsl:sequence select="xs:string(' ')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:sequence
					select="xs:string( if ($number[contains(.,'-')]) 
					then concat('($' , format-number($digits, '#,##0.00') , ')') 
					else concat('$', format-number($digits, '#,##0.00') ) )"
				/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>

	<xsl:template match="/STL_Invoice">
		<xsl:variable name="time" select="xs:time(concat(SummarySection/InvoiceDueTime, ':00'))"
			as="xs:time"/>

		<html>
			<head>
				<title>Settlement Invoice</title>
				<style type="text/css">
					body{
					    padding-left:30px;
					}
					body,
					td,
					th{
					    font-family:Arial, Helvetica, sans-serif;
					    font-size:70% !important;
					}
					.detail td{
					    border-color:#999;
					    border-bottom-style:solid;
					    border-bottom-width:1px;
					}
					.subtotal td{
					    border-color:black;
					    border-bottom-style:solid;
					    border-bottom-width:2px;
					    font-weight:bold;
					    text-align:right;
					}
					.subtotal td:first-child{
					    padding-right:10px;
					}
					.total td{
					    border-color:black;
					    border-bottom-style:solid;
					    border-bottom-width:2px;
					    font-weight:bold;
					    text-align:right;
					}
					.remittance tr td{
					    border-color:#999;
					    border-bottom-style:solid;
					    border-width:0px 0px 1px 0px;
					}
					.remittance th{
					    text-align:left;
					    padding:10px 3px 2px 3px;
					}
					.bold{
					    font-weight:bold;
					}
					.padding-normal td,
					.padding-normal tr td{
					    padding:1px 3px 1px 3px;
					}
					.padding-remittance{
					    padding:5px 3px 4px 3px;
					}
					.highlight{
					    background-color:#D7E2F2;
					    padding:3px;
					}
					.paragraph{
					    line-height:125%;
					}
					.data-header th{
					    font-weight:normal;
					    text-align:left;
					    padding:3px;
					}
					.detail-start{
					    border-color:#999;
					    border-bottom-style:solid;
					    border-bottom-width:thin;
					}
					.invoice-type{
					    font-weight:bold;
					    font-size:80% !important;
					    text-align:right;
					    width:75%;
					}
					.uppercase{
					    text-transform:uppercase;
					}
					.space-bottom{
					    padding-bottom:1em;
					}
					.space-right{
					    padding-right:1em;
					}</style>
			</head>
			<body>
				<table width="670px" border="0" cellspacing="0" cellpadding="0">
					<tr>
						<td style="padding:0px; vertical-align:text-top">
							<table width="100%" border="0" cellspacing="0" cellpadding="0">
								<tr>
									<td>
										<img src="{$path}images/logo_trans.gif" width="126"
											height="51" alt="ERCOT Logo"/>
									</td>
									<td class="invoice-type uppercase" colspan="2">Settlement
										Invoice</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td>
							<table width="100%" border="0" cellspacing="0" cellpadding="0">
								<tbody align="right">
									<tr>
										<td class="space-right">Invoice No:</td>
										<td class="bold" width="150px">
											<xsl:value-of select="SummarySection/InvoiceID"/>
										</td>
									</tr>
									<tr>
										<td class="space-bottom space-right">Invoice Date:</td>
										<td class="bold space-bottom">
											<xsl:value-of select="SummarySection/InvoiceDate"/>
										</td>
									</tr>
									<tr>
										<td class="space-right"> Payments are due to ERCOT by
												<xsl:value-of
												select="format-time($time, 
											'[h]:[m01] [PN]')"
											/></td>
										<td class="bold">
											<xsl:value-of select="SummarySection/InvoiceDueDate"/>
										</td>
									</tr>
									<tr>
										<td class="space-bottom space-right"> Payments will be made
											to Invoice Recipients by <xsl:value-of
												select="format-time($time, 
											'[h]:[m01] [PN]')"
											/></td>
										<td class="bold space-bottom">
											<xsl:value-of select="SummarySection/InvoicePayoutDate"
											/>
										</td>
									</tr>
									<tr>
										<td class="bold uppercase space-right">Amount owed
											(due):</td>
										<td class="bold highlight">
											<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight padding-normal">
						<td colspan="2" class="uppercase">Invoice Recipient</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="100%" border="0" cellpadding="0" cellspacing="0">
								<colgroup>
									<col width="80"/>
									<col/>
								</colgroup>
								<tbody class="padding-normal">
									<tr>
										<td>Name:</td>
										<td class="bold">
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientAccountName"
											/>
										</td>
									</tr>
									<tr>
										<td>ID:</td>
										<td class="bold">
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientAccountID"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<table width="100%" border="0" cellspacing="0" cellpadding="0"
								style="table-layout:fixed; word-wrap:break-word">
								<colgroup align="left" width="13%"/>
								<colgroup align="left" width="48%"/>
								<colgroup align="left" width="11%"/>
								<colgroup align="right" width="14%"/>
								<colgroup align="right" width="14%"/>
								<thead class="data-header highlight">
									<tr>
										<th class="uppercase">Category</th>
										<th class="uppercase">Statement ID</th>
										<th class="uppercase">Operating Day</th>
										<th class="uppercase">Statement Amount</th>
										<th class="uppercase" style="text-align:center"
											>Subtotal</th>
									</tr>
								</thead>
								<tbody class="padding-normal">
									<tr>
										<td colspan="5">
											<xsl:text>&nbsp;</xsl:text>
										</td>
									</tr>
									<xsl:for-each select="InvoiceData/InvoiceGroup">
										<xsl:variable name="name" select="@name" as="xs:string"/>
										<xsl:for-each select="InvoiceDetail">
											<tr class="detail">
												<td class="bold">
												<xsl:choose>
													<xsl:when test="position() = 1">
														<xsl:value-of select="$name"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>&nbsp;</xsl:text>
													</xsl:otherwise>
												</xsl:choose>
												</td>
												<td>
												<xsl:value-of select="StatementID"/>
												</td>
												<td align="right">
												<xsl:value-of select="OperatingDate"/>
												</td>
												<td align="right">
												<xsl:value-of
												select="ercot:number-to-dollar(StatementAmount)"/>
												</td>
												<td>&nbsp;</td>
											</tr>
										</xsl:for-each>
										<xsl:if test="count(InvoiceDetail) >= 1">
											<tr class="subtotal">
												<td colspan="4"><xsl:value-of select="$name"/>
													Subtotal</td>
												<td class="highlight">
													<xsl:value-of
													select="ercot:number-to-dollar(Subtotal)"/>
												</td>
											</tr>
										</xsl:if>
									</xsl:for-each>
									<!-- Total -->
									<tr class="total">
										<td class="uppercase" colspan="4">Net Amount Owed (Due)</td>
										<td class="highlight"><xsl:value-of
											select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"/></td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2"><xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight padding-normal">
						<td colspan="2">REMITTANCE INFORMATION</td>
					</tr>
					<tr>
						<td colspan="2" class="remittance">
							<table width="100%" border="0" cellspacing="0" cellpadding="0">
								<colgroup align="left" width="20%" class="bold"/>
								<colgroup span="2" align="left"/>
								<thead class="padding-remittance">
									<tr>
										<th> </th>
										<th>ERCOT Account</th>
										<th>Recipient Account</th>
									</tr>
								</thead>
								<tbody class="padding-normal">
									<tr>
										<td>Account Name</td>
										<td>
											<xsl:value-of select="AccountSection/ERCOT_SECTION/ERCOTBankName"/>
										</td>
										<td>
											<xsl:value-of select="AccountSection/RecipientSection/RecipientBankName"/>
										</td>
									</tr>
									<tr>
										<td>Bank Name</td>
										<td>
											<xsl:value-of select="AccountSection/ERCOT_SECTION/ERCOTFinancialInst"/>
										</td>
										<td>
											<xsl:value-of select="AccountSection/RecipientSection/RecipientFinancialInst"/>
										</td>
									</tr>
									<tr>
										<td>ABA Routing Number</td>
										<td>
											<xsl:value-of select="AccountSection/ERCOT_SECTION/ERCOTRoutingNum"/>
										</td>
										<td>
											<xsl:value-of select="AccountSection/RecipientSection/RecipientRoutingNum"/>
										</td>
									</tr>
									<tr>
										<td>Account Number</td>
										<td>
											<xsl:value-of select="AccountSection/ERCOT_SECTION/ERCOTBankAcctNum"/>
										</td>
										<td>
											<xsl:value-of select="AccountSection/RecipientSection/RecipientBankAcctNum"/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2"><xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr>
						<td colspan="2" class="bold padding-normal">Overdue Terms</td>
					</tr>
					<tr>
						<td colspan="2" class="paragraph padding-normal">
							<xsl:value-of select="SummarySection/InvoiceTerms"/>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
