<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#xA0;">]>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ercot="http://www.ercot.com/functions" xmlns:xs="http://www.w3.org/2001/XMLSchema">
	
	<xsl:param name="path"/>
	
	<xsl:output method="html" indent="yes"/>
	<!--doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
		doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" encoding="UTF-8"/>-->
	
	<!-- converts -444444.00 to ($444,444.00) OR 444444.00 to $444,444.00 -->
	<xsl:function name="ercot:number-to-dollar" as="xs:string">
		<xsl:param name="number" as="xs:string?"/>
		<xsl:variable name="digits"
			select="if ($number[contains(.,'-')]) then number(substring-after($number,'-')) else number($number)"/>
		<xsl:choose>
			<xsl:when test="string-length($number) = 0">
				<xsl:sequence select="xs:string(' ')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:sequence
					select="xs:string( if ($number[contains(.,'-')]) 
					then concat('($' , format-number($digits, '#,##0.00') , ')') 
					else concat('$', format-number($digits, '#,##0.00') ) )"
				/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
    
    
    <xsl:template match="/">
        <xsl:apply-templates
        select="SSN_Invoice | SUI_INVOICE | SUR_INVOICE"/>
    </xsl:template>
        
    <xsl:template
        match="SSN_Invoice | SUI_INVOICE | SUR_INVOICE">
    	<xsl:variable as="xs:time" name="time"
    		select="xs:time(concat(SummarySection/InvoiceDueTime, ':00'))"/>
        <html>
			<head>
				<title>Securitization 
					Uplift Charge Invoice </title>
					<!--<xsl:choose>
					<xsl:when test="name(.) eq 'SNI_INVOICE'">
						
					</xsl:when>
						<xsl:when test="name(.) eq 'SNR_INVOICE'"><title>Securitization 
						Subchapter N Reallocation Invoice</title></xsl:when>
				   </xsl:choose> 
				   </title>-->
				<style type="text/css">
					<script language="javascript" type="text/javascript" src="{$path}scripts/twistie.js">
					<xsl:comment>using this comment to force saxon to not reformat as script/ b/c IE doesn's support it</xsl:comment>
				</script>
				
					body {
					    padding-left : 30px;
					}
					body,
					td,
					th {
					    font-family : Arial, Helvetica, sans-serif;
					    font-size : 70% !important;
					}
					.detail td {
					    border-color : #999;
					    border-bottom-style : solid;
					    border-bottom-width : 1px;
					}
					.subtotal td {
					    border-color : black;
					    border-bottom-style : solid;
					    border-bottom-width : 2px;
					    font-weight : bold;
					    text-align : right;
					}
					.subtotal td:first-child {
					    padding-right : 10px;
					}
					.total td {
					    border-color : black;
					    border-bottom-style : solid;
					    border-bottom-width : 2px;
					    font-weight : bold;
					    text-align : right;
					}
					.remittance tr td {
					    border-color : #999;
					    border-bottom-style : solid;
					    border-width : 0px 0px 1px 0px;
					}
					.remittance th {
					    text-align : left;
					    padding : 10px 3px 2px 3px;
					}
					.bold {
					    font-weight : bold;
					}
					.padding-normal td,
					.padding-normal tr td {
					    padding : 1px 3px 1px 3px;
					}
					.padding-remittance {
					    padding : 5px 3px 4px 3px;
					}
					.highlight {
					    background-color : #D7E2F2;
					    padding : 3px;
					}
					.paragraph {
					    line-height : 125%;
					}
					.data-header th {
					    font-weight : normal;
					    text-align : left;
					    padding : 3px;
					}
					.detail-start {
					    border-color : #999;
					    border-bottom-style : solid;
					    border-bottom-width : thin;
					}
					.invoice-type {
					    font-weight : bold;
					    font-size : 80% !important;
					    text-align : right;
					    width : 75%;
					}
					.uppercase {
					    text-transform : uppercase;
					}
					.space-bottom {
					    padding-bottom : 1em;
					}
					.space-right {
					    padding-right : 1em;
					}</style>
			</head>
			<body>
				<table border="0" cellpadding="0" cellspacing="0" width="670px">
					<tr>
						<td style="padding:0px; vertical-align:text-top">
							<table border="0" cellpadding="0" cellspacing="0" width="100%">
								<tr>
									<td>
										<img alt="ERCOT Logo" height="51"
											src="{$path}images/logo-ercot.png" width="126"/>
									</td>
									<td class="invoice-type uppercase" colspan="2">
										<xsl:choose>
											<xsl:when test="name(.) eq 'SUI_INVOICE'">
												Securitization 
												Uplift Charge Initial Invoice
											</xsl:when>
											<xsl:when test="name(.) eq 'SUR_INVOICE'">Securitization 
												Uplift Charge Reallocation Invoice </xsl:when>
											</xsl:choose> 
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td>
							<table border="0" cellpadding="0" cellspacing="0" width="100%">
								<tbody align="right">
									<tr>
										<td class="space-right">Invoice No:</td>
										<td class="bold" width="150px">
											<xsl:value-of select="SummarySection/InvoiceID"/>
										</td>
									</tr>
									<tr>
										<td class="space-bottom space-right">Invoice Date:</td>
										<td class="bold space-bottom">
											<xsl:value-of select="SummarySection/InvoiceDate"/>
										</td>
									</tr>
									<tr>
										<td class="space-right"> Payments are due to ERCOT by
											<xsl:value-of
												select="format-time($time,             '[h]:[m01] [PN]')"
											/></td>
										<td class="bold">
											<xsl:value-of select="SummarySection/InvoiceDueDate"/>
										</td>
									</tr>
									<tr>
										<td class="space-bottom space-right"> Payments will be made
											to Invoice Recipients by <xsl:value-of
												select="format-time($time,             '[h]:[m01] [PN]')"
											/>
										</td>
										<td class="bold space-bottom">
											<xsl:value-of select="SummarySection/InvoicePayoutDate"
											/>
										</td>
									</tr>
									<tr>
										<td class="bold uppercase space-right">Amount owed
											(due):</td>
										<td class="bold highlight">
											<xsl:value-of
												select="ercot:number-to-dollar(SummarySection/InvoiceTotal)"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight padding-normal">
						<td class="uppercase" colspan="2">Invoice Recipient</td>
					</tr>
					<tr>
						<td colspan="2">
							<table border="0" cellpadding="0" cellspacing="0" width="100%">
								<colgroup>
									<col width="80"/>
									<col/>
								</colgroup>
								<tbody class="padding-normal">
									<tr>
										<td>Name:</td>
										<td class="bold">
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientAccountName"
											/>
										</td>
									</tr>
									<tr>
										<td>ID:</td>
										<td class="bold">
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientAccountID"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight padding-normal">
						<td class="uppercase" colspan="2">Invoice Description</td>
					</tr>
					<tr>
						<td colspan="2"> LASUCAMT - Load-Allocated Securitization Uplift 
							Charge Amount </td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<xsl:apply-templates select="InvoiceData"/>
					
					
							
					
					
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr class="highlight padding-normal">
						<td colspan="2">REMITTANCE INFORMATION</td>
					</tr>
					<tr>
						<td class="remittance" colspan="2">
							<table border="0" cellpadding="0" cellspacing="0" width="100%">
								<colgroup align="left" class="bold" width="20%"/>
								<colgroup align="left" span="2"/>
								<thead class="padding-remittance">
									<tr>
										<th> </th>
										<th>ERCOT Account</th>
										<th>Recipient Account</th>
									</tr>
								</thead>
								<tbody class="padding-normal">
									<tr>
										<td>Account Name</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTBankName"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientBankName"
											/>
										</td>
									</tr>
									<tr>
										<td>Bank Name</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTFinancialInst"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientFinancialInst"
											/>
										</td>
									</tr>
									<tr>
										<td>ABA Routing Number</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTRoutingNum"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientRoutingNum"
											/>
										</td>
									</tr>
									<tr>
										<td>Account Number</td>
										<td>
											<xsl:value-of
												select="AccountSection/ERCOT_SECTION/ERCOTBankAcctNum"
											/>
										</td>
										<td>
											<xsl:value-of
												select="AccountSection/RecipientSection/RecipientBankAcctNum"
											/>
										</td>
									</tr>
								</tbody>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<xsl:text>&nbsp;</xsl:text>
						</td>
					</tr>
					<tr>
						<td class="bold padding-normal" colspan="2">Overdue Terms</td>
					</tr>
					<tr>
						<td class="paragraph padding-normal" colspan="2">
							<xsl:value-of select="SummarySection/InvoiceTerms"/>
						</td>
					</tr>
				</table>
			</body>
		</html>
    </xsl:template>
    
	<xsl:template match="InvoiceData">
		<tr>
			<td colspan="2">
				<table border="0" cellpadding="0" cellspacing="0"
					style="table-layout:fixed; word-wrap:break-word" width="100%">
					<colgroup align="left" width="25%"/>
					<colgroup align="left" width="15%"/>
					<colgroup align="left" width="25%"/>
					<colgroup align="left" width="11%"/>
					<colgroup align="right" width="14%"/>
					<colgroup align="right" width="14%"/>
					<colgroup align="right" width="14%"/>
					<thead class="data-header highlight">
						<tr>
							<th class="uppercase">Category</th>
							<th class="uppercase">Operating Day</th>
							<th class="uppercase">Settlement Type</th>
							<th class="uppercase">Channel</th>
							<th class="uppercase" style="text-align:right">Amount</th>
							<th class="uppercase" style="text-align:right">Billable Amount</th>
							<th class="uppercase" style="text-align:right"
								>Subtotal</th>
						</tr>
					</thead>
					<tbody class="padding-normal">
						<xsl:apply-templates select="Category"/>
						
						<tr>
							<td colspan="7">
								<xsl:text>&nbsp;</xsl:text>
							</td>
						</tr>
						<tr class="total">
							<td class="uppercase" colspan="6">Net Amount Owed (Due)</td>
							<td class="highlight">
								<xsl:value-of   select="ercot:number-to-dollar(../SummarySection/InvoiceTotal)"
								/>
							</td>
						</tr>
					</tbody>
				</table>
			</td>
		</tr>
		
	</xsl:template>
	
    <xsl:template match="Category">
        <xsl:apply-templates select="OperatingDate"/>
        <xsl:apply-templates select="Subtotal"/>
    </xsl:template>
    
    <xsl:template match="OperatingDate">
        <xsl:apply-templates select="OperatingDateDetail"/>
    	<tr>
    		<td class="detail-start"  colspan="7">
    			
    		</td>
    	</tr>
    </xsl:template>
    
    <xsl:template match="OperatingDateDetail">
        <tr>
            <td>
            	<xsl:choose>
            		<xsl:when test="count(preceding-sibling::OperatingDateDetail) + count(../preceding-sibling::*/OperatingDateDetail) = 0">
            			<xsl:value-of select="ancestor::Category/@Name"/>
            		</xsl:when>
            		<xsl:otherwise> </xsl:otherwise>
            	</xsl:choose>
            </td>
            <td>
            	<xsl:choose>
            		<xsl:when test="position() = 1">
            			<xsl:value-of select="ancestor::OperatingDate/@Date"/>
            		</xsl:when>
            		<xsl:otherwise>&nbsp;</xsl:otherwise>
            	</xsl:choose>
            </td>
            <td>
                <xsl:value-of select="SettlementType"/>
            </td>
            <td>
                <xsl:value-of select="Channel"/>
            </td>
        	<td align="right">
            	<xsl:value-of select="ercot:number-to-dollar(Amount)"/>
            </td>
        	<td align="right">
            	<xsl:value-of select="ercot:number-to-dollar(Billamount)"/>
            </td>
            <td>&nbsp;</td>
        </tr>
    </xsl:template>
    
    <xsl:template match="Subtotal">
        <tr class="subtotal">
        	<td colspan="6" align="right" >
            	<xsl:value-of select="ancestor::Category/@Name"/>&nbsp; SUBTOTAL</td>
        	<td align="right" class="highlight">
            	<xsl:value-of select="ercot:number-to-dollar(.)"/>
            </td>
        </tr>
    </xsl:template>
    
    
            
</xsl:stylesheet>